@@ -45,6 +45,7 @@
 #include "src/scan.h"
 #include "src/util.h"
 #include "src/watchlist.h"
+#include "src/band.h"
 
 static struct l_queue *known_networks;
 static size_t num_known_hidden_networks;
@@ -173,9 +174,10 @@ static const char *known_network_get_path(const struct network_info *network)
 
 	for (i = 0; network->ssid[i] && pos < sizeof(path); i++)
 		pos += snprintf(path + pos, sizeof(path) - pos, "%02x",
-				network->ssid[i]);
+				(unsigned char)network->ssid[i]);
 
-	snprintf(path + pos, sizeof(path) - pos, "_%s",
+	if (pos < sizeof(path))
+		snprintf(path + pos, sizeof(path) - pos, "_%s",
 			security_to_str(network->type));
 	path[sizeof(path) - 1] = '\0';
 
@@ -466,6 +468,10 @@ void known_network_update(struct network_info *network,
 	known_network_set_autoconnect(network, new->is_autoconnectable);
 
 	memcpy(&network->config, new, sizeof(struct network_config));
+
+	WATCHLIST_NOTIFY(&known_network_watches,
+				known_networks_watch_func_t,
+				KNOWN_NETWORKS_EVENT_UPDATED, network);
 }
 
 bool known_networks_foreach(known_networks_foreach_func_t function,
@@ -856,7 +862,8 @@ static struct l_queue *known_frequencies_from_string(char *freq_set_str)
 
 		t = strtoul(freq_set_str, &freq_set_str, 10);
 
-		if (unlikely(errno == ERANGE || !t || t > 6000))
+		if (unlikely(errno == ERANGE || !t ||
+					!band_freq_to_channel(t, NULL)))
 			goto error;
 
 		known_freq = l_new(struct known_frequency, 1);
